==> ejc-ztpcct-impl-3.0.0-20230921.055845-31-sources.jar: com/ejianc/ztpc/bean/GreatDangerProjectEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 危大工程
 * 
 * @author generator
 * 
 */
 @TableName("ct_great_danger_project")
public class GreatDangerProjectEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目组织ID
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="org_name")
    private String orgName; // 项目组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="cons_scheme_id")
    private Long consSchemeId; // 施工方案ID
    @TableField(value="cons_scheme_name")
    private String consSchemeName; // 施工方案名称
    @TableField(value="cons_scheme_type")
    private Long consSchemeType; // 施工方案类别--字典ct_cons_scheme_type
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value="expert_atte_date")
    private Date expertAtteDate; // 专家认证时间
    @TableField(value="disclosure_date")
    private Date disclosureDate; // 交底日期
    @TableField(value="acceptance_date")
    private Date acceptanceDate; // 验收日期
    @TableField(value="examine_super")
    private String examineSuper; // 检查监督
    @TableField(value="implementation")
    private String implementation; // 实施情况
    @TableField(value="complete_date")
    private Date completeDate; // 完工日期
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="expert_argument_file")
    private Long expertArgumentFile; // 专项方案专家论证报告附件
    @TableField(value="technology_disclosure_file")
    private Long technologyDisclosureFile; // 安全技术交底附件
    @TableField(value="disclosure_user_file")
    private Long disclosureUserFile; // 参与交底人员签名附件
    @TableField(value="user_register_file")
    private Long userRegisterFile; // 作业人员登记表附件
    @TableField(value="user_record_file")
    private Long userRecordFile; // 作业人员履历附件
    @TableField(value="examine_acceptance_file")
    private Long examineAcceptanceFile; // 检查验收表附件
    @TableField(value="polling_record_file")
    private Long pollingRecordFile; // 巡检记录附件
    @TableField(value="substation_record_file")
    private Long substationRecordFile; // 监督旁站记录附件
    @TableField(value="state")
    private String state; // 状态
    @TableField(value="state_name")
    private String stateName; // 状态名称

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getConsSchemeId() {
        return consSchemeId;
    }

    public void setConsSchemeId(Long consSchemeId) {
        this.consSchemeId = consSchemeId;
    }
    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }
    public Long getConsSchemeType() {
        return consSchemeType;
    }

    public void setConsSchemeType(Long consSchemeType) {
        this.consSchemeType = consSchemeType;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }
    public Date getExpertAtteDate() {
        return expertAtteDate;
    }

    public void setExpertAtteDate(Date expertAtteDate) {
        this.expertAtteDate = expertAtteDate;
    }
    public Date getDisclosureDate() {
        return disclosureDate;
    }

    public void setDisclosureDate(Date disclosureDate) {
        this.disclosureDate = disclosureDate;
    }
    public Date getAcceptanceDate() {
        return acceptanceDate;
    }

    public void setAcceptanceDate(Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    public String getExamineSuper() {
        return examineSuper;
    }

    public void setExamineSuper(String examineSuper) {
        this.examineSuper = examineSuper;
    }
    public String getImplementation() {
        return implementation;
    }

    public void setImplementation(String implementation) {
        this.implementation = implementation;
    }
    public Date getCompleteDate() {
        return completeDate;
    }

    public void setCompleteDate(Date completeDate) {
        this.completeDate = completeDate;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getExpertArgumentFile() {
        return expertArgumentFile;
    }

    public void setExpertArgumentFile(Long expertArgumentFile) {
        this.expertArgumentFile = expertArgumentFile;
    }
    public Long getTechnologyDisclosureFile() {
        return technologyDisclosureFile;
    }

    public void setTechnologyDisclosureFile(Long technologyDisclosureFile) {
        this.technologyDisclosureFile = technologyDisclosureFile;
    }
    public Long getDisclosureUserFile() {
        return disclosureUserFile;
    }

    public void setDisclosureUserFile(Long disclosureUserFile) {
        this.disclosureUserFile = disclosureUserFile;
    }
    public Long getUserRegisterFile() {
        return userRegisterFile;
    }

    public void setUserRegisterFile(Long userRegisterFile) {
        this.userRegisterFile = userRegisterFile;
    }
    public Long getUserRecordFile() {
        return userRecordFile;
    }

    public void setUserRecordFile(Long userRecordFile) {
        this.userRecordFile = userRecordFile;
    }
    public Long getExamineAcceptanceFile() {
        return examineAcceptanceFile;
    }

    public void setExamineAcceptanceFile(Long examineAcceptanceFile) {
        this.examineAcceptanceFile = examineAcceptanceFile;
    }
    public Long getPollingRecordFile() {
        return pollingRecordFile;
    }

    public void setPollingRecordFile(Long pollingRecordFile) {
        this.pollingRecordFile = pollingRecordFile;
    }
    public Long getSubstationRecordFile() {
        return substationRecordFile;
    }

    public void setSubstationRecordFile(Long substationRecordFile) {
        this.substationRecordFile = substationRecordFile;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getStateName() {
        return stateName;
    }

    public void setStateName(String stateName) {
        this.stateName = stateName;
    }
}

==> ejc-ztpcct-impl-3.0.0-20231008.063616-38-sources.jar: com/ejianc/ztpc/bean/GreatDangerProjectEntity.java <==
package com.ejianc.ztpc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 危大工程
 * 
 * @author generator
 * 
 */
 @TableName("ct_great_danger_project")
public class GreatDangerProjectEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目组织ID
    @TableField(value="org_code")
    private String orgCode; // 项目组织编码
    @TableField(value="org_name")
    private String orgName; // 项目组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value="cons_scheme_id")
    private Long consSchemeId; // 施工方案ID
    @TableField(value="cons_scheme_name")
    private String consSchemeName; // 施工方案名称
    @TableField(value="cons_scheme_type")
    private Long consSchemeType; // 施工方案类别--字典ct_cons_scheme_type
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value="project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value="expert_atte_date")
    private Date expertAtteDate; // 专家认证时间
    @TableField(value="disclosure_date")
    private Date disclosureDate; // 交底日期
    @TableField(value="acceptance_date")
    private Date acceptanceDate; // 验收日期
    @TableField(value="examine_super")
    private String examineSuper; // 检查监督
    @TableField(value="implementation")
    private String implementation; // 实施情况
    @TableField(value="complete_date")
    private Date completeDate; // 完工日期
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="expert_argument_file")
    private Long expertArgumentFile; // 专项方案专家论证报告附件
    @TableField(value="technology_disclosure_file")
    private Long technologyDisclosureFile; // 安全技术交底附件
    @TableField(value="disclosure_user_file")
    private Long disclosureUserFile; // 参与交底人员签名附件
    @TableField(value="user_register_file")
    private Long userRegisterFile; // 作业人员登记表附件
    @TableField(value="user_record_file")
    private Long userRecordFile; // 作业人员履历附件
    @TableField(value="examine_acceptance_file")
    private Long examineAcceptanceFile; // 检查验收表附件
    @TableField(value="polling_record_file")
    private Long pollingRecordFile; // 巡检记录附件
    @TableField(value="substation_record_file")
    private Long substationRecordFile; // 监督旁站记录附件
    @TableField(value="state")
    private String state; // 状态
    @TableField(value="state_name")
    private String stateName; // 状态名称
    @TableField(value="construction_scheme_file")
    private Long constructionSchemeFile; // 施工方案附件
    @TableField(value="project_disclosure_file")
    private Long projectDisclosureFile; // 项目交底附件

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getConsSchemeId() {
        return consSchemeId;
    }

    public void setConsSchemeId(Long consSchemeId) {
        this.consSchemeId = consSchemeId;
    }
    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }
    public Long getConsSchemeType() {
        return consSchemeType;
    }

    public void setConsSchemeType(Long consSchemeType) {
        this.consSchemeType = consSchemeType;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }
    public Date getExpertAtteDate() {
        return expertAtteDate;
    }

    public void setExpertAtteDate(Date expertAtteDate) {
        this.expertAtteDate = expertAtteDate;
    }
    public Date getDisclosureDate() {
        return disclosureDate;
    }

    public void setDisclosureDate(Date disclosureDate) {
        this.disclosureDate = disclosureDate;
    }
    public Date getAcceptanceDate() {
        return acceptanceDate;
    }

    public void setAcceptanceDate(Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    public String getExamineSuper() {
        return examineSuper;
    }

    public void setExamineSuper(String examineSuper) {
        this.examineSuper = examineSuper;
    }
    public String getImplementation() {
        return implementation;
    }

    public void setImplementation(String implementation) {
        this.implementation = implementation;
    }
    public Date getCompleteDate() {
        return completeDate;
    }

    public void setCompleteDate(Date completeDate) {
        this.completeDate = completeDate;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getExpertArgumentFile() {
        return expertArgumentFile;
    }

    public void setExpertArgumentFile(Long expertArgumentFile) {
        this.expertArgumentFile = expertArgumentFile;
    }
    public Long getTechnologyDisclosureFile() {
        return technologyDisclosureFile;
    }

    public void setTechnologyDisclosureFile(Long technologyDisclosureFile) {
        this.technologyDisclosureFile = technologyDisclosureFile;
    }
    public Long getDisclosureUserFile() {
        return disclosureUserFile;
    }

    public void setDisclosureUserFile(Long disclosureUserFile) {
        this.disclosureUserFile = disclosureUserFile;
    }
    public Long getUserRegisterFile() {
        return userRegisterFile;
    }

    public void setUserRegisterFile(Long userRegisterFile) {
        this.userRegisterFile = userRegisterFile;
    }
    public Long getUserRecordFile() {
        return userRecordFile;
    }

    public void setUserRecordFile(Long userRecordFile) {
        this.userRecordFile = userRecordFile;
    }
    public Long getExamineAcceptanceFile() {
        return examineAcceptanceFile;
    }

    public void setExamineAcceptanceFile(Long examineAcceptanceFile) {
        this.examineAcceptanceFile = examineAcceptanceFile;
    }
    public Long getPollingRecordFile() {
        return pollingRecordFile;
    }

    public void setPollingRecordFile(Long pollingRecordFile) {
        this.pollingRecordFile = pollingRecordFile;
    }
    public Long getSubstationRecordFile() {
        return substationRecordFile;
    }

    public void setSubstationRecordFile(Long substationRecordFile) {
        this.substationRecordFile = substationRecordFile;
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getStateName() {
        return stateName;
    }

    public void setStateName(String stateName) {
        this.stateName = stateName;
    }

    public Long getConstructionSchemeFile() {
        return constructionSchemeFile;
    }

    public void setConstructionSchemeFile(Long constructionSchemeFile) {
        this.constructionSchemeFile = constructionSchemeFile;
    }

    public Long getProjectDisclosureFile() {
        return projectDisclosureFile;
    }

    public void setProjectDisclosureFile(Long projectDisclosureFile) {
        this.projectDisclosureFile = projectDisclosureFile;
    }
}
